@@ -487,6 +487,10 @@ class ParametersLEDET:
             for k in variableGroup.__annotations__:
                 print(k, self.getAttribute(variableGroup, k))
         else:
+            self.variableGroupInputs = asdict(self.Inputs)
+            self.variableGroupOptions = asdict(self.Options)
+            self.variableGroupPlots = asdict(self.Plots)
+            self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
                 print(k, variableGroup[k])
 
@@ -705,12 +709,12 @@ class ParametersLEDET:
             if (attribute == "overwrite_f_internalVoids_inGroup"):
                 ofiVg = self.getAttribute(variableGroup, attribute)
                 if len(ofiVg) == 0:
-                    currentRow = currentRow + 1
+                    #currentRow = currentRow + 1
                     continue
             if (attribute == "overwrite_f_externalVoids_inGroup"):
                 ofiVg = self.getAttribute(variableGroup, attribute)
                 if len(ofiVg) == 0:
-                    currentRow = currentRow + 1
+                    #currentRow = currentRow + 1
                     continue
             if currentRow in variableGroup.BlankRows[1]:
                 currentRow = currentRow + 1
