@@ -439,7 +439,7 @@ class ParametersCOSIM:
                 f.write('\n')
 
     def copyCOSIMfiles(self, circuit, nameFileSING, StimulusFile, LEDETFiles, nameMagnet,N_LEDET=1):
-        nameFolderCosimModel = os.path.join(os.getcwd(), 'cosim_model_' + circuit)
+        nameFolderCosimModel = self.nameFolderCosimModel
         print(nameFolderCosimModel)
         # Copy PSPICE model file
         nameFolderPSpiceModel = os.path.join(nameFolderCosimModel, 'PSpice')
@@ -476,7 +476,7 @@ class ParametersCOSIM:
 
         return LEDET_Fs
 
-    def prepareLEDETFiles(self, files, N_PAR):
+    def prepareLEDETFiles(self, files, N_PAR=1):
         TurnNumber = 0
 
         if type(files) == list:
@@ -492,7 +492,7 @@ class ParametersCOSIM:
         TurnNumber_All = TurnNumber*N_PAR
 
         if TurnNumber_All >= 10000:
-            print("You are trying to simulate ",str(TurnNumber_All),"in paralell mode. \n")
+            print("You are trying to simulate ",str(TurnNumber_All),"in parallel mode. \n")
             maxN_PAR = np.floor(10000/TurnNumber)
             print("Consider not to user more than ", str(maxN_PAR)," parallel Simulations.")
 
